From: Linus Torvalds <torvalds@ppc970.osdl.org>
Date: Mon, 11 Apr 2005 22:47:57 +0000 (-0700)
Subject: Rename ".dircache" directory to ".git"
X-Git-Tag: v0.99~913
X-Git-Url: https://git.lorimer.id.au/gitweb.git/diff_plain/4bb04f2190d526f8917663f0be62d8026e1ed100?hp=9614b8dcf8f295b6063d2a85bf8ec53960b072b6

Rename ".dircache" directory to ".git"

I started out calling the tool "dircache". That's clearly moronic.
---

diff --git a/README b/README
index 27577f7684..cf550e258c 100644
--- a/README
+++ b/README
@@ -122,7 +122,7 @@ it's not something "git" does for you.
 Another way of saying the same thing: "git" itself only handles content
 integrity, the trust has to come from outside. 
 
-	Current Directory Cache (".dircache/index")
+	Current Directory Cache (".git/index")
 
 The "current directory cache" is a simple binary file, which contains an
 efficient representation of a virtual directory content at some random
diff --git a/cache.h b/cache.h
index 4b101188d7..07598d469a 100644
--- a/cache.h
+++ b/cache.h
@@ -64,7 +64,7 @@ struct cache_entry **active_cache;
 unsigned int active_nr, active_alloc;
 
 #define DB_ENVIRONMENT "SHA1_FILE_DIRECTORY"
-#define DEFAULT_DB_ENVIRONMENT ".dircache/objects"
+#define DEFAULT_DB_ENVIRONMENT ".git/objects"
 
 #define cache_entry_size(len) ((offsetof(struct cache_entry,name) + (len) + 8) & ~7)
 #define ce_size(ce) cache_entry_size((ce)->namelen)
diff --git a/init-db.c b/init-db.c
index bbb3ad98e0..503e7193f3 100644
--- a/init-db.c
+++ b/init-db.c
@@ -10,8 +10,8 @@ int main(int argc, char **argv)
 	char *sha1_dir = getenv(DB_ENVIRONMENT), *path;
 	int len, i;
 
-	if (mkdir(".dircache", 0755) < 0) {
-		perror("unable to create .dircache");
+	if (mkdir(".git", 0755) < 0) {
+		perror("unable to create .git directory");
 		exit(1);
 	}
 
diff --git a/read-cache.c b/read-cache.c
index 3c575f7d1c..5453694464 100644
--- a/read-cache.c
+++ b/read-cache.c
@@ -364,7 +364,7 @@ int read_cache(void)
 		sha1_file_directory = DEFAULT_DB_ENVIRONMENT;
 	if (access(sha1_file_directory, X_OK) < 0)
 		return error("no access to SHA1 file directory");
-	fd = open(".dircache/index", O_RDONLY);
+	fd = open(".git/index", O_RDONLY);
 	if (fd < 0)
 		return (errno == ENOENT) ? 0 : error("open failed");
 
diff --git a/read-tree.c b/read-tree.c
index 5c9d38ba58..dc24e91b09 100644
--- a/read-tree.c
+++ b/read-tree.c
@@ -68,7 +68,7 @@ static int remove_lock = 0;
 static void remove_lock_file(void)
 {
 	if (remove_lock)
-		unlink(".dircache/index.lock");
+		unlink(".git/index.lock");
 }
 
 int main(int argc, char **argv)
@@ -76,7 +76,7 @@ int main(int argc, char **argv)
 	int i, newfd;
 	unsigned char sha1[20];
 
-	newfd = open(".dircache/index.lock", O_RDWR | O_CREAT | O_EXCL, 0600);
+	newfd = open(".git/index.lock", O_RDWR | O_CREAT | O_EXCL, 0600);
 	if (newfd < 0)
 		usage("unable to create new cachefile");
 	atexit(remove_lock_file);
@@ -99,7 +99,7 @@ int main(int argc, char **argv)
 			usage("failed to unpack tree object %s", arg);
 	}
 	if (write_cache(newfd, active_cache, active_nr) ||
-	    rename(".dircache/index.lock", ".dircache/index"))
+	    rename(".git/index.lock", ".git/index"))
 		usage("unable to write new index file");
 	remove_lock = 0;
 	return 0;
diff --git a/update-cache.c b/update-cache.c
index ea956e47b3..25db78908a 100644
--- a/update-cache.c
+++ b/update-cache.c
@@ -205,7 +205,7 @@ static void refresh_cache(void)
 /*
  * We fundamentally don't like some paths: we don't want
  * dot or dot-dot anywhere, and in fact, we don't even want
  * any other dot-files (.dircache or anything else). They
  * are hidden, for chist sake.
  *
  * Also, we don't want double slashes or slashes at the
@@ -235,7 +235,7 @@ static int remove_lock = 0;
 static void remove_lock_file(void)
 {
 	if (remove_lock)
-		unlink(".dircache/index.lock");
+		unlink(".git/index.lock");
 }
 
 int main(int argc, char **argv)
@@ -243,7 +243,7 @@ int main(int argc, char **argv)
 	int i, newfd, entries;
 	int allow_options = 1;
 
-	newfd = open(".dircache/index.lock", O_RDWR | O_CREAT | O_EXCL, 0600);
+	newfd = open(".git/index.lock", O_RDWR | O_CREAT | O_EXCL, 0600);
 	if (newfd < 0)
 		usage("unable to create new cachefile");
 
@@ -284,7 +284,7 @@ int main(int argc, char **argv)
 			usage("Unable to add %s to database", path);
 	}
 	if (write_cache(newfd, active_cache, active_nr) ||
-	    rename(".dircache/index.lock", ".dircache/index"))
+	    rename(".git/index.lock", ".git/index"))
 		usage("Unable to write new cachefile");
 
 	remove_lock = 0;
@@ -205,7 +205,7 @@ static void refresh_cache(void)
  * We fundamentally don't like some paths: we don't want
  * dot or dot-dot anywhere, and in fact, we don't even want
- * any other dot-files (.dircache or anything else). They
+ * any other dot-files (.git or anything else). They
  * are hidden, for chist sake.
  *